@@ -1,5 +1,5 @@
-#ifndef NSTD_NSTD_H_INCLUDED
-#define NSTD_NSTD_H_INCLUDED
+#ifndef NSTD_H_INCLUDED
+#define NSTD_H_INCLUDED
 #include "nstd/alloc.h"
 #include "nstd/audio.h"
 #include "nstd/collections.h"
